@@ -7,7 +7,7 @@ use serde::{Deserialize, Serialize};
 #[argh(subcommand, name = "east")]
 pub struct East {
     /// 保存数据的 CSV 路径文件名。默认为当前路径下 eastmoney.csv 文件。
-    #[argh(option, short = 'j', default = r#""eastmoney.csv".into()"#)]
+    #[argh(option, short = 'o', default = r#""eastmoney.csv".into()"#)]
     pub output: String,
 
     /// 指定前一日复权 csv 文件。
@@ -31,6 +31,10 @@ pub struct East {
     /// 打印响应数据。
     #[argh(switch, short = 's')]
     pub show: bool,
+
+    /// 可选。指定表名称，默认为 `rustdx.tmp`。
+    #[argh(option, short = 't', default = "String::from(\"rustdx.tmp\")")]
+    pub table: String,
 }
 
 impl East {
@@ -66,28 +70,30 @@ impl East {
             println!("text:\n{}\njson:\n{:?}", text, json);
         }
 
-        let file = std::fs::File::create(&self.output)?;
-        let mut wrt = csv::Writer::from_writer(file);
-        for row in &json.data.diff {
-            if let F32::Yes(_) = row.close {
-                wrt.serialize(row)?;
+        {
+            let file = std::fs::File::create(&self.output)?;
+            let mut wrt = csv::Writer::from_writer(file);
+            for row in &json.data.diff {
+                if let F32::Yes(_) = row.close {
+                    wrt.serialize(row)?;
+                }
             }
         }
-
-        Ok(())
+        self.insert_clickhouse()
     }
 
     pub fn run_previous(&self) -> Result<()> {
         let text = crate::io::RUNTIME.block_on(self.get())?;
-        let mut json = Self::json(&text)?;
+        let json = Self::json(&text)?;
         if self.show {
             println!("text:\n{}\njson:\n{:?}", text, json);
         }
+        self._run_previous(json)?;
+        self.insert_clickhouse()
+    }
 
-        let previous = crate::io::pre_factor(self.previous
-                                                 .as_ref()
-                                                 .ok_or(anyhow::anyhow!("请检查 previous \
-                                                                         文件的路径"))?)?;
+    fn _run_previous(&self, mut json: EastMarket) -> Result<()> {
+        let previous = crate::io::previous_csv_table(&self.previous, &self.table)?;
         let file = std::fs::File::create(&self.output)?;
         let mut wrt = csv::Writer::from_writer(file);
         for row in &mut json.data.diff {
@@ -121,7 +127,6 @@ impl East {
                 wrt.serialize(row)?;
             }
         }
-
         Ok(())
     }
 
@@ -132,6 +137,16 @@ impl East {
             self.run_no_previous()
         }
     }
+
+    fn insert_clickhouse(&self) -> Result<()> {
+        if self.output.eq("clickhouse") {
+            // 插入 clickhouse 时，不保存解析结果。
+            // 如果需要保存结果，则使用 `rustdx east -o output.csv` 指定 csv 文件。
+            crate::io::insert_clickhouse(&self.output, &self.table, false)
+        } else {
+            Ok(())
+        }
+    }
 }
 
 /// 用于（反）序列化：比如读取东方财富网页返回的 json ；把结果写入到 csv
