@@ -81,11 +81,7 @@ pub fn run_csv_fq_previous(cmd: &DayCmd) -> Result<()> {
     let gbbq = Gbbq::filter_hashmap(Gbbq::iter(&mut bytes[4..]));
 
     // 前收
-    let previous = if let Some(Some(path)) = cmd.previous.as_ref().map(|p| p.to_str()) {
-        if path == "clickhouse" { clickhouse_factor(&cmd.table) } else { pre_factor(dbg!(path)) }?
-    } else {
-        return Err(anyhow!("请检查 gbbq 路径"));
-    };
+    let previous = previous_csv_table(&cmd.previous, &cmd.table)?;
 
     // 股票列表
     let hm = cmd.stocklist();
@@ -143,20 +139,12 @@ fn print(dir: &Path, count: usize, take: usize) {
     }
 }
 
-/// 读取前收盘价（前 factor ）数据
-pub fn pre_factor(p: impl AsRef<Path>) -> Result<std::collections::HashMap<u32, Factor>> {
-    Ok(csv::Reader::from_reader(File::open(p)?).deserialize::<Factor>()
-                                               .filter_map(|f| f.ok())
-                                               .map(|f| (f.code.parse().unwrap(), f))
-                                               .collect())
-}
-
 fn database_table(table: &str) -> (&str, &str) {
     let pos = table.find('.').unwrap();
     table.split_at(pos) // (database_name, table_name)
 }
 
-fn setup_clickhouse(fq: bool, table: &str) -> Result<()> {
+pub fn setup_clickhouse(fq: bool, table: &str) -> Result<()> {
     let create_database = format!("CREATE DATABASE IF NOT EXISTS {}", database_table(table).0);
     let output = Command::new("clickhouse-client").args(["--query", &create_database]).output()?;
     check_output(output);
@@ -201,24 +189,49 @@ fn setup_clickhouse(fq: bool, table: &str) -> Result<()> {
     Ok(())
 }
 
-/// clickhouse-client --query "INSERT INTO table FORMAT CSVWithNames" < clickhouse[.csv]
-pub fn run_clickhouse(cmd: &DayCmd) -> Result<()> {
+pub fn insert_clickhouse(output: &impl AsRef<Path>, table: &str, keep: bool) -> Result<()> {
     use subprocess::{Exec, Redirection};
-    setup_clickhouse(cmd.gbbq.is_some(), &cmd.table)?;
-    cmd.run_csv()?;
-    let file = File::open(&cmd.output)?;
-    let query = format!("INSERT INTO {} FORMAT CSVWithNames", cmd.table);
+    let query = format!("INSERT INTO {} FORMAT CSVWithNames", table);
     let capture = Exec::cmd("clickhouse-client").args(&["--query", &query])
-                                                .stdin(Redirection::File(file))
+                                                .stdin(Redirection::File(File::open(output)?))
                                                 .capture()?;
     println!("stdout:\n{}stderr:\n{}", capture.stdout_str(), capture.stderr_str());
     assert!(capture.success());
-    keep_csv(&cmd.output, cmd.keep_csv)?;
+    keep_csv(output, keep)?;
     Ok(())
 }
 
+/// 需要日线 clickhouse csv 文件
+#[test]
+fn test_insert_clickhouse() -> Result<()> {
+    setup_clickhouse(true, "rustdx.tmp")?;
+    insert_clickhouse(&"clickhouse", "rustdx.tmp", true)
+}
+
+type Previous = Result<std::collections::HashMap<u32, Factor>>;
+
+pub fn previous_csv_table(path: &Option<std::path::PathBuf>, table: &str) -> Previous {
+    if let Some(Some(path)) = path.as_ref().map(|p| p.to_str()) {
+        if path == "clickhouse" {
+            clickhouse_factor_csv(table)
+        } else {
+            previous_csv(path)
+        }
+    } else {
+        Err(anyhow!("请检查 gbbq 路径"))
+    }
+}
+
+/// 读取前收盘价（前 factor ）数据
+pub fn previous_csv(p: impl AsRef<Path>) -> Previous {
+    Ok(csv::Reader::from_reader(File::open(p)?).deserialize::<Factor>()
+                                               .filter_map(|f| f.ok())
+                                               .map(|f| (f.code.parse().unwrap(), f))
+                                               .collect())
+}
+
 /// 获取当前最新 factor
-fn clickhouse_factor(table: &str) -> Result<std::collections::HashMap<u32, Factor>> {
+fn clickhouse_factor_csv(table: &str) -> Previous {
     let args =
         ["--query",
          &format!("WITH (
@@ -237,7 +250,7 @@ fn clickhouse_factor(table: &str) -> Result<std::collections::HashMap<u32, Facto
                   table)];
     let output = Command::new("clickhouse-client").args(args).output()?;
     check_output(output);
-    pre_factor("factor.csv")
+    previous_csv("factor.csv")
 }
 
 /// TODO: 与数据库有关的，把库名、表名可配置
@@ -266,9 +279,9 @@ fn check_output(output: std::process::Output) {
     assert!(output.status.success());
 }
 
-fn keep_csv(fname: &str, keep: bool) -> io::Result<()> {
+fn keep_csv(fname: &impl AsRef<Path>, keep: bool) -> io::Result<()> {
     if keep {
-        fs::rename(fname, format!("{}.csv", fname))
+        fs::rename(fname, fname.as_ref().with_extension("csv"))
     } else {
         fs::remove_file(fname)
     }
